@@ -5,24 +5,24 @@ use std::process::Command;
 
 #[cfg(feature = "sync")]
 fn main() {
-    let mut process = PtyProcess::spawn(Command::new("cat")).expect("Error while spawning process");
+    let mut p = PtyProcess::spawn(Command::new("cat")).unwrap();
 
     println!("Now you're in interacting mode");
     println!("To return control back to main type CTRL-]");
 
-    process.interact().expect("Failed to start interact");
+    let status = p.interact().expect("Failed to start interact");
 
-    println!("Quiting");
+    println!("Quiting status {:?}", status);
 }
 
 #[cfg(feature = "async")]
 fn main() {
-    let mut process = PtyProcess::spawn(Command::new("cat")).expect("Error while spawning process");
+    let mut p = PtyProcess::spawn(Command::new("cat")).unwrap();
 
     println!("Now you're in interacting mode");
     println!("To return control back to main type CTRL-]");
 
-    futures_lite::future::block_on(process.interact()).expect("Failed to start interact");
+    let status = futures_lite::future::block_on(p.interact()).expect("Failed to start interact");
 
-    println!("Quiting");
+    println!("Quiting status {:?}", status);
 }
