@@ -1,5 +1,7 @@
 use crate::control_code::ControlCode;
 use crate::stream::Stream;
+#[cfg(feature = "async")]
+use futures_lite::AsyncWriteExt;
 use nix::errno::{self, Errno};
 use nix::fcntl::{fcntl, open, FcntlArg, FdFlag, OFlag};
 use nix::libc::{self, winsize, STDERR_FILENO, STDIN_FILENO, STDOUT_FILENO};
@@ -249,8 +251,17 @@ impl PtyProcess {
     /// Checks if a process is still exists.
     ///
     /// It's a non blocking operation.
+    ///
+    /// Keep in mind that after calling this method process might be marked as DEAD by kernel,
+    /// because a check of its status.
+    /// Therefore second call to [Self::status] or [Self::is_alive] might return a different status.
     pub fn is_alive(&self) -> Result<bool> {
-        is_alive(self.status())
+        let status = self.status();
+        match status {
+            Ok(status) if status == WaitStatus::StillAlive => Ok(true),
+            Ok(_) | Err(Error::Sys(Errno::ECHILD)) | Err(Error::Sys(Errno::ESRCH)) => Ok(false),
+            Err(err) => Err(err),
+        }
     }
 
     /// Try to force a child to terminate.
@@ -360,10 +371,58 @@ impl PtyProcess {
     pub fn send_intr(&mut self) -> io::Result<()> {
         self.stream.write_all(&[self.intr_char])
     }
-}
 
-#[cfg(feature = "async")]
-use futures_lite::AsyncWriteExt;
+    /// Interact gives control of the child process to the interactive user (the
+    /// human at the keyboard).
+    ///
+    /// Returns a status of a process ater interactions.
+    /// Why it's crusial to return a status is after check of is_alive the actuall
+    /// status might be gone.
+    ///
+    /// Keystrokes are sent to the child process, and
+    /// the `stdout` and `stderr` output of the child process is printed.
+    ///
+    /// When the user types the `escape_character` this method will return control to a running process.
+    /// The escape_character will not be transmitted.
+    /// The default for escape_character is entered as `Ctrl-]`, the very same as BSD telnet.
+    ///
+    /// This simply echos the child `stdout` and `stderr` to the real `stdout` and
+    /// it echos the real `stdin` to the child `stdin`.
+    pub fn interact(&mut self) -> io::Result<WaitStatus> {
+        // flush buffers
+        self.flush()?;
+
+        let stdin_copy_fd = dup(0).map_err(nix_error_to_io)?;
+        let stdin = unsafe { std::fs::File::from_raw_fd(stdin_copy_fd) };
+        let mut stdin_stream = Stream::new(stdin);
+
+        let mut buf = [0; 512];
+        loop {
+            let status = self.status();
+            if !matches!(status, Ok(WaitStatus::StillAlive)) {
+                return status.map_err(nix_error_to_io);
+            }
+
+            if let Some(n) = self.try_read(&mut buf)? {
+                std::io::stdout().write_all(&buf[..n])?;
+                std::io::stdout().flush()?;
+            }
+
+            if let Some(n) = stdin_stream.try_read(&mut buf)? {
+                for i in 0..n {
+                    // Ctrl-]
+                    if buf[i] == ControlCode::GroupSeparator.into() {
+                        // it might be too much to call a `status()` here,
+                        // do it just in case.
+                        return self.status().map_err(nix_error_to_io);
+                    }
+
+                    self.write_all(&buf[i..i + 1])?;
+                }
+            }
+        }
+    }
+}
 
 #[cfg(feature = "async")]
 impl PtyProcess {
@@ -423,6 +482,67 @@ impl PtyProcess {
     pub async fn send_intr(&mut self) -> io::Result<()> {
         self.stream.write_all(&[self.intr_char]).await
     }
+
+    /// Interact gives control of the child process to the interactive user (the
+    /// human at the keyboard).
+    ///
+    /// Returns a status of a process ater interactions.
+    /// Why it's crusial to return a status is after check of is_alive the actuall
+    /// status might be gone.
+    ///
+    /// Keystrokes are sent to the child process, and
+    /// the `stdout` and `stderr` output of the child process is printed.
+    ///
+    /// When the user types the `escape_character` this method will return control to a running process.
+    /// The escape_character will not be transmitted.
+    /// The default for escape_character is entered as `Ctrl-]`, the very same as BSD telnet.
+    ///
+    /// This simply echos the child `stdout` and `stderr` to the real `stdout` and
+    /// it echos the real `stdin` to the child `stdin`.
+    pub async fn interact(&mut self) -> io::Result<WaitStatus> {
+        // flush buffers
+        self.flush().await?;
+
+        let stdin_copy_fd = dup(0).map_err(nix_error_to_io)?;
+        let stdin = unsafe { std::fs::File::from_raw_fd(stdin_copy_fd) };
+        let mut stdin_stream = Stream::new(stdin);
+        
+        let mut buf = [0; 512];
+        loop {
+            let status = self.status();
+            if !matches!(status, Ok(WaitStatus::StillAlive)) {
+                return status.map_err(nix_error_to_io);
+            }
+
+            if let Some(n) = self.try_read(&mut buf).await? {
+                std::io::stdout().write_all(&buf[..n])?;
+                std::io::stdout().flush()?;
+            }
+
+            if let Some(n) = stdin_stream.try_read(&mut buf).await? {
+                for i in 0..n {
+                    // Ctrl-]
+                    if buf[i] == ControlCode::GroupSeparator.into() {
+                        // it might be too much to call a `status()` here,
+                        // do it just in case.
+                        return self.status().map_err(nix_error_to_io);
+                    }
+
+                    self.write_all(&buf[i..i + 1]).await?;
+                }
+            }
+        }
+    }
+}
+
+fn nix_error_to_io(err: nix::Error) -> io::Error {
+    match err.as_errno() {
+        Some(code) => io::Error::from_raw_os_error(code as _),
+        None => io::Error::new(
+            io::ErrorKind::Other,
+            "Unexpected error type conversion from nix to io",
+        ),
+    }
 }
 
 impl Drop for PtyProcess {
@@ -447,14 +567,6 @@ impl DerefMut for PtyProcess {
     }
 }
 
-fn is_alive(status: Result<WaitStatus>) -> Result<bool> {
-    match status {
-        Ok(status) if status == WaitStatus::StillAlive => Ok(true),
-        Ok(_) | Err(Error::Sys(Errno::ECHILD)) | Err(Error::Sys(Errno::ESRCH)) => Ok(false),
-        Err(err) => Err(err),
-    }
-}
-
 fn set_term_size(fd: i32, cols: u16, rows: u16) -> Result<()> {
     ioctl_write_ptr_bad!(_set_window_size, libc::TIOCSWINSZ, winsize);
 
